@@ -42,6 +42,7 @@ text_fuzzy_default_error_handler (const char * source_file,
     fprintf (stderr, "%s:%d: ", source_file, source_line_number);
     va_start (args, message);
     vfprintf (stderr, message, args);
+    fprintf (stderr, "\n");
     return 0;
 }
 
@@ -959,7 +960,7 @@ STATIC FUNC (close) (fuzzy_file_t * ff)
    string found is returned in "* nearest_ptr". */
 
 FUNC (scan_file) (text_fuzzy_t * text_fuzzy, char * file_name,
-                  char ** nearest_ptr)
+                  char ** nearest_ptr, int * nearest_length_ptr)
 {
     fuzzy_file_t ff = {0};
     char * nearest;
@@ -979,11 +980,12 @@ FUNC (scan_file) (text_fuzzy_t * text_fuzzy, char * file_name,
             found = 1;
 	    if (! nearest) {
 		nearest = malloc (ff.b.length + 1);
+		FAIL (! nearest, memory_failure);
 	    }
 	    else {
 		nearest = realloc (nearest, ff.b.length + 1);
+		FAIL (! nearest, memory_failure);
 	    }
-	    FAIL (! nearest, memory_failure);
 	    strncpy (nearest, ff.b.text, ff.b.length);
 	    nearest[ff.b.length] = '\0';
         }
@@ -1005,6 +1007,12 @@ FUNC (scan_file) (text_fuzzy_t * text_fuzzy, char * file_name,
     OK;
 }
 
+FUNC (scan_file_free) (char * nearest)
+{
+    free (nearest);
+    OK;
+}
+
 FUNC (alphabet_rejections) (text_fuzzy_t * text_fuzzy, int * r)
 {
     * r = text_fuzzy->alphabet_rejections;
